@@ -124,7 +124,7 @@ class VariableUrGroup(ReadonlyVariable):
     def get(self):
         gid = self.Get('ur_gid')
         try:
-            return grp.getgrgid(str(gid)).gr_name
+            return grp.getgrgid(int(gid)).gr_name
         except (KeyError, TypeError):
             return ""
 
